@@ -1,4 +1,4 @@
-## read.nexus.R (2007-05-03)
+## read.nexus.R (2007-12-22)
 
 ##   Read Tree File in Nexus Format
 
@@ -139,27 +139,19 @@ read.nexus <- function(file, tree.names = NULL)
                 }
             }
         }
-        trees[[i]] <- obj
         ## Check here that the root edge is not incorrectly represented
         ## in the object of class "phylo" by simply checking that there
-        ## is a bifurcation at the root (node "-1")
-        if (sum(trees[[i]]$edge[, 1] == "-1") == 1 && dim(trees[[i]]$edge)[1] > 1) {
-            warning("The root edge is apparently not correctly represented\nin your tree: this may be due to an extra pair of\nparentheses in your file; the returned object has been\ncorrected but your file may not be in a valid Newick\nformat")
-            ind <- which(trees[[i]]$edge[, 1] == "-1")
-            trees[[i]]$root.edge <- trees[[i]]$edge.length[ind]
-            trees[[i]]$edge.length <- trees[[i]]$edge.length[-ind]
-            trees[[i]]$edge <- trees[[i]]$edge[-ind, ]
-            for (j in 1:length(trees[[i]]$edge))
-              if (as.numeric(trees[[i]]$edge[j]) < 0)
-                trees[[i]]$edge[j] <- as.character(as.numeric(trees[[i]]$edge[j]) + 1)
-            ## Check a second time and if there is still a problem...!!!
-            if(sum(trees[[i]]$edge[, 1] == "-1") == 1)
-              stop("There is apparently two root edges in your file: cannot read tree file")
+        ## is a bifurcation at the root
+        ROOT <- length(obj$tip.label) + 1
+        if (sum(obj$edge[, 1] == ROOT) == 1 && dim(obj$edge)[1] > 1) {
+            stop(paste("There is apparently two root edges in your file: cannot read tree file.\n  Reading NEXUS file aborted at tree no.", i, sep = ""))
         }
+        trees[[i]] <- obj
     }
     if (nb.tree == 1) trees <- trees[[1]] else {
-        names(trees) <- if (is.null(tree.names)) paste("tree", 1:nb.tree, sep = "") else tree.names
-        class(trees) <- c("multi.tree", "phylo")
+        names(trees) <- if (is.null(tree.names))
+            paste("tree", 1:nb.tree, sep = "") else tree.names
+        class(trees) <- "multiPhylo"
     }
     if (length(grep("[\\/]", file)) == 1) attr(trees, "origin") <- file
     else attr(trees, "origin") <- paste(getwd(), file, sep = "/")
